Activation Registered

This is a one-time process, If you have previously registered or accessed your account, please select "Login your Account" above.

# Activate My Account

Please enter the PIN you received in the mail or have the PIN sent to the email address we have on record

Membership ID
What's this?
Pin code

I don't have my PIN

Need help? Click here to view a brief tutorial or click here to contact us

Your Membership ID can be found on your Membership card or on your publication mailing label in the format of ID# xxxxx9999.